<?xml version="1.0"?>

<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<xsl:output method="html" indent="no" encoding="UTF-8"/>


<xsl:template match="/monster">
<html>
<body>
<table border='1' width='100%'>
  <tr>
    <td width='100%'>
	<b><xsl:value-of select="name"/></b>
	<xsl:text> </xsl:text>
    </td>
  </tr>
  <tr>
    <td>
	<xsl:value-of select="size/category"/>
	<xsl:text> </xsl:text>
	<xsl:value-of select="size/type"/>
	<xsl:text> </xsl:text>
	<xsl:value-of select="size/subtype"/>;
	<xsl:text> </xsl:text>

	AL <xsl:value-of select="alignment/abbr"/>;
	<xsl:text> </xsl:text>
    </td>
  </tr>
  <tr>
    <td>
      <table width='100%'>
	<tr>
	  <td width='33%' valign='top'>
	    <table width='100%'>
	      <xsl:for-each select="abilities/ability">
	        <tr>
	          <td width='20%'>
		    <xsl:value-of select="abbr"/>
	  	  </td>
	  	  <td width='80%'>
		    <xsl:value-of select="base"/>
	  	  </td>
		</tr>
	      </xsl:for-each>
	    </table>
	  </td>
	  <td width='33%' valign='top'>
	    <table width='100%'>
	      <xsl:for-each select="saving-throws/saving-throw">
		<tr>
		  <td width='20%'>
		    <xsl:value-of select="abbr"/>
		  </td>
		  <td width='80%'>
		    <xsl:variable name="save" select="sum(modifiers/modifier[@name != 'misc']/@value)"/>
		    <xsl:if test="$save >= 0">
			+
		    </xsl:if>
		    <xsl:value-of select="$save"/>
		  </td>
		</tr>
	      </xsl:for-each>
	      <tr>
		<td>
		  <xsl:variable name="init" select="sum(initiative/modifiers/modifier[@name != 'misc']/@value)"/>
		  <xsl:text>Init </xsl:text>
		</td>
		<td>
		  <xsl:if test="$init >= 0">
			+
		  </xsl:if>
		  <xsl:value-of select="$init"/>
		</td>
	      </tr>
	      <tr>
		<td valign='top'>
		  Spd
		</td>
		<td>
		  <xsl:for-each select="//speeds/speed">
		    <xsl:choose>
		      <xsl:when test="name = 'Base'">
			<xsl:value-of select="value"/>
		      </xsl:when>
		      <xsl:otherwise>
			<xsl:value-of select="name"/>
			<xsl:text> </xsl:text>
			<xsl:value-of select="value"/>
		      </xsl:otherwise>
		    </xsl:choose>
		    <br/>
	 	  </xsl:for-each>
		</td>
	      </tr>
	    </table>
	  </td>
	  <td width='34%' valign='top'>
	    <xsl:if test="challenge-rating != 0">
		CR <xsl:value-of select="challenge-rating"/><br/>
	    </xsl:if>
	    HD
	    <xsl:text> </xsl:text>
	    <xsl:for-each select="hit-dice/hit-die">
		<xsl:value-of select="die"/><xsl:value-of select="bonus"/>
		<xsl:text> </xsl:text>
		(<xsl:value-of select="class"/>)
		<xsl:choose>
		<xsl:when test="position() = last()">
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>, </xsl:text>
		</xsl:otherwise>
		</xsl:choose>
	    </xsl:for-each><br/>
	    AC <xsl:value-of select="sum(armor-class/modifiers/modifier[@name != 'misc']/@value)"/>
	    <xsl:text> </xsl:text>
	    <xsl:if test="spell-resistance != ''">
		SR <xsl:value-of select="spell-resistance"/>
		<xsl:text> </xsl:text>
	    </xsl:if><br/>
	    hp <xsl:value-of select="hit-points"/>
	  </td>
	</tr>
      </table>
    </td>
  </tr>
  <tr>
    <td>
	<xsl:variable name="melee" select="sum(attacks/melee/modifiers/modifier[@name != 'misc']/@value)"/>
	<b><xsl:text>Atk </xsl:text></b>
	<xsl:if test="$melee >= 0">
		+
	</xsl:if>
	<xsl:value-of select="$melee"/>
	<xsl:text> base melee, </xsl:text>

	<xsl:variable name="ranged" select="sum(attacks/ranged/modifiers/modifier[@name != 'misc']/@value)"/>
	<xsl:if test="$ranged >= 0">
		+
	</xsl:if>
	<xsl:value-of select="$ranged"/>
	<xsl:text> base ranged; </xsl:text><br/>
	<xsl:for-each select="equiped-items/weapons">
		<xsl:for-each select="weapon">
			<xsl:value-of select="bonus"/>
			<xsl:choose>
			<xsl:when test="position() = last()">
			</xsl:when>
			<xsl:otherwise>
				<xsl:text>/</xsl:text>
			</xsl:otherwise>
			</xsl:choose>
		</xsl:for-each>
		<xsl:text> </xsl:text>(
		<xsl:for-each select="weapon">
			<xsl:value-of select="name"/>, <xsl:value-of select="damage"/>
			<xsl:choose>
			<xsl:when test="position() = last()">
			</xsl:when>
			<xsl:otherwise>
			<xsl:text>; </xsl:text>
			</xsl:otherwise>
			</xsl:choose>
		</xsl:for-each>
		);<xsl:text> </xsl:text>
	</xsl:for-each>
    </td>
  </tr>
  <tr>
    <td>
	<xsl:for-each select="features/special-attacks/special-attack">
		<xsl:if test="position() = 1">
			<b><xsl:text>SA: </xsl:text></b>
		</xsl:if>
		<xsl:value-of select="."/>

		<xsl:choose>
		<xsl:when test="position() = last()">
			<xsl:text>; </xsl:text>
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>, </xsl:text>
		</xsl:otherwise>
		</xsl:choose>
	</xsl:for-each>
    </td>
  </tr>
  <tr>
    <td>
	<xsl:for-each select="features/special-qualities/special-quality">
		<xsl:if test="position() = 1">
			<b><xsl:text>SQ: </xsl:text></b>
		</xsl:if>
		<xsl:value-of select="."/>

		<xsl:choose>
		<xsl:when test="position() = last()">
			<xsl:text>; </xsl:text>
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>, </xsl:text>
		</xsl:otherwise>
		</xsl:choose>
	</xsl:for-each>
    </td>
  </tr>
  <tr>
    <td>
	<xsl:for-each select="features/race-features/race-feature">
		<xsl:if test="position() = 1">
			<b><xsl:text>Racial Features: </xsl:text></b>
		</xsl:if>
		<xsl:value-of select="."/>

		<xsl:choose>
		<xsl:when test="position() = last()">
			<xsl:text>; </xsl:text>
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>, </xsl:text>
		</xsl:otherwise>
		</xsl:choose>
	</xsl:for-each>
    </td>
  </tr>
  <tr>
    <td>
	<xsl:for-each select="skills/skill[modifiers/modifier[@name = 'rank' or @name = 'race' or @name = 'magic' or @name = 'feat' or @name = 'other']/@value &gt; 0]">
		<xsl:sort select="string(.)"/>
		<xsl:if test="position() = 1">
			<br/><br/><b>Skills: </b>
		</xsl:if>
		<xsl:value-of select="name"/>
			<xsl:text> </xsl:text>
		<xsl:if test="sum(modifiers/modifier[@name != 'misc']/@value) >= 0">
			 +
		</xsl:if>
		<xsl:value-of select="sum(modifiers/modifier[@name != 'misc']/@value)"/>
		<xsl:choose>
		<xsl:when test="position() = last()">
			<xsl:text>. </xsl:text>
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>, </xsl:text>
		</xsl:otherwise>
		</xsl:choose>
	</xsl:for-each>

	<xsl:for-each select="features/feats/feat">
		<xsl:sort select="string(.)"/>
		<xsl:if test="position() = 1">
			<br/><b>Feats: </b>
		</xsl:if>
		<xsl:value-of select="name"/>
		<xsl:choose>
		<xsl:when test="position() = last()">
			<xsl:text>.</xsl:text>
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>, </xsl:text>
		</xsl:otherwise>
		</xsl:choose>
	</xsl:for-each>


	<xsl:for-each select="spells-known/class">
		<xsl:if test="full-name != 'Cleric'">

		<br/><br/><b>Spells Known <xsl:value-of select="name"/>: </b>
<br/>
		<xsl:if test="count(spell[level = '0']) > 0">
			<xsl:text>0 - </xsl:text>
			<xsl:for-each select="spell[level = '0']">
				<xsl:sort select="string(.)"/>
				<i><xsl:value-of select="name"/></i>
				<xsl:choose>
				<xsl:when test="position() != last()">
					<xsl:text>, </xsl:text>
				</xsl:when>
				</xsl:choose>
			</xsl:for-each>
		</xsl:if>
<br/>
		<xsl:if test="count(spell[level = '1']) > 0">
			<xsl:text>1st - </xsl:text>
			<xsl:for-each select="spell[level = '1']">
				<xsl:sort select="string(.)"/>
				<i><xsl:value-of select="name"/></i>
				<xsl:choose>
				<xsl:when test="position() != last()">
					<xsl:text>, </xsl:text>
				</xsl:when>
				</xsl:choose>
			</xsl:for-each>
		</xsl:if>
<br/>
		<xsl:if test="count(spell[level = '2']) > 0">
			<xsl:text>2nd - </xsl:text>
			<xsl:for-each select="spell[level = '2']">
				<xsl:sort select="string(.)"/>
				<i><xsl:value-of select="name"/></i>
				<xsl:choose>
				<xsl:when test="position() != last()">
					<xsl:text>, </xsl:text>
				</xsl:when>
				</xsl:choose>
			</xsl:for-each>
		</xsl:if>
<br/>
		<xsl:if test="count(spell[level = '3']) > 0">
			<xsl:text>3rd - </xsl:text>
			<xsl:for-each select="spell[level = '3']">
				<xsl:sort select="string(.)"/>
				<i><xsl:value-of select="name"/></i>
				<xsl:choose>
				<xsl:when test="position() != last()">
					<xsl:text>, </xsl:text>
				</xsl:when>
				</xsl:choose>
			</xsl:for-each>
		</xsl:if>
<br/>
		<xsl:if test="count(spell[level = '4']) > 0">
			<xsl:text>4th - </xsl:text>
			<xsl:for-each select="spell[level = '4']">
				<xsl:sort select="string(.)"/>
				<i><xsl:value-of select="name"/></i>
				<xsl:choose>
				<xsl:when test="position() != last()">
					<xsl:text>, </xsl:text>
				</xsl:when>
				</xsl:choose>
			</xsl:for-each>
		</xsl:if>
<br/>
		<xsl:if test="count(spell[level = '5']) > 0">
			<xsl:text>5th - </xsl:text>
			<xsl:for-each select="spell[level = '5']">
				<xsl:sort select="string(.)"/>
				<i><xsl:value-of select="name"/></i>
				<xsl:choose>
				<xsl:when test="position() != last()">
					<xsl:text>, </xsl:text>
				</xsl:when>
				</xsl:choose>
			</xsl:for-each>
		</xsl:if>
<br/>
		<xsl:if test="count(spell[level = '6']) > 0">
			<xsl:text>6th - </xsl:text>
			<xsl:for-each select="spell[level = '6']">
				<xsl:sort select="string(.)"/>
				<i><xsl:value-of select="name"/></i>
				<xsl:choose>
				<xsl:when test="position() != last()">
					<xsl:text>, </xsl:text>
				</xsl:when>
				</xsl:choose>
			</xsl:for-each>
		</xsl:if>
<br/>
		<xsl:if test="count(spell[level = '7']) > 0">
			<xsl:text>7th - </xsl:text>
			<xsl:for-each select="spell[level = '7']">
				<xsl:sort select="string(.)"/>
				<i><xsl:value-of select="name"/></i>
				<xsl:choose>
				<xsl:when test="position() != last()">
					<xsl:text>, </xsl:text>
				</xsl:when>
				</xsl:choose>
			</xsl:for-each>
		</xsl:if>
<br/>
		<xsl:if test="count(spell[level = '8']) > 0">
			<xsl:text>8th - </xsl:text>
			<xsl:for-each select="spell[level = '8']">
				<xsl:sort select="string(.)"/>
				<i><xsl:value-of select="name"/></i>
				<xsl:choose>
				<xsl:when test="position() != last()">
					<xsl:text>, </xsl:text>
				</xsl:when>
				</xsl:choose>
			</xsl:for-each>
		</xsl:if>
<br/>
		<xsl:if test="count(spell[level = '9']) > 0">
			<xsl:text>9th - </xsl:text>
			<xsl:for-each select="spell[level = '9']">
				<xsl:sort select="string(.)"/>
				<i><xsl:value-of select="name"/></i>
				<xsl:choose>
				<xsl:when test="position() != last()">
					<xsl:text>, </xsl:text>
				</xsl:when>
				</xsl:choose>
			</xsl:for-each>
		</xsl:if>
		<xsl:text>.</xsl:text>

		</xsl:if>
	</xsl:for-each>

	<xsl:for-each select="spells-prepared/class">
		<br/><br/><b>Spells Prepared <xsl:value-of select="name"/>: </b>
<br/>
		<xsl:if test="count(spell[level = '0']) > 0">
			<xsl:text>0 - </xsl:text>
			<xsl:for-each select="spell[level = '0']">
				<xsl:sort select="string(.)"/>
				<i><xsl:value-of select="name"/><xsl:apply-templates select="count"/></i>
				<xsl:choose>
				<xsl:when test="position() != last()">
					<xsl:text>, </xsl:text>
				</xsl:when>
				</xsl:choose>
			</xsl:for-each>
		</xsl:if>
<br/>
		<xsl:if test="count(spell[level = '1']) > 0">
			<xsl:text>1st - </xsl:text>
			<xsl:for-each select="spell[level = '1']">
				<xsl:sort select="string(.)"/>
				<i><xsl:value-of select="name"/><xsl:apply-templates select="count"/></i>
				<xsl:choose>
				<xsl:when test="position() != last()">
					<xsl:text>, </xsl:text>
				</xsl:when>
				</xsl:choose>
			</xsl:for-each>
		</xsl:if>
<br/>
		<xsl:if test="count(spell[level = '2']) > 0">
			<xsl:text>2nd - </xsl:text>
			<xsl:for-each select="spell[level = '2']">
				<xsl:sort select="string(.)"/>
				<i><xsl:value-of select="name"/><xsl:apply-templates select="count"/></i>
				<xsl:choose>
				<xsl:when test="position() != last()">
					<xsl:text>, </xsl:text>
				</xsl:when>
				</xsl:choose>
			</xsl:for-each>
		</xsl:if>
<br/>
		<xsl:if test="count(spell[level = '3']) > 0">
			<xsl:text>3rd - </xsl:text>
			<xsl:for-each select="spell[level = '3']">
				<xsl:sort select="string(.)"/>
				<i><xsl:value-of select="name"/><xsl:apply-templates select="count"/></i>
				<xsl:choose>
				<xsl:when test="position() != last()">
					<xsl:text>, </xsl:text>
				</xsl:when>
				</xsl:choose>
			</xsl:for-each>
		</xsl:if>
<br/>
		<xsl:if test="count(spell[level = '4']) > 0">
			<xsl:text>4th - </xsl:text>
			<xsl:for-each select="spell[level = '4']">
				<xsl:sort select="string(.)"/>
				<i><xsl:value-of select="name"/><xsl:apply-templates select="count"/></i>
				<xsl:choose>
				<xsl:when test="position() != last()">
					<xsl:text>, </xsl:text>
				</xsl:when>
				</xsl:choose>
			</xsl:for-each>
		</xsl:if>
<br/>
		<xsl:if test="count(spell[level = '5']) > 0">
			<xsl:text>5th - </xsl:text>
			<xsl:for-each select="spell[level = '5']">
				<xsl:sort select="string(.)"/>
				<i><xsl:value-of select="name"/><xsl:apply-templates select="count"/></i>
				<xsl:choose>
				<xsl:when test="position() != last()">
					<xsl:text>, </xsl:text>
				</xsl:when>
				</xsl:choose>
			</xsl:for-each>
		</xsl:if>
<br/>
		<xsl:if test="count(spell[level = '6']) > 0">
			<xsl:text>6th - </xsl:text>
			<xsl:for-each select="spell[level = '6']">
				<xsl:sort select="string(.)"/>
				<i><xsl:value-of select="name"/><xsl:apply-templates select="count"/></i>
				<xsl:choose>
				<xsl:when test="position() != last()">
					<xsl:text>, </xsl:text>
				</xsl:when>
				</xsl:choose>
			</xsl:for-each>
		</xsl:if>
<br/>
		<xsl:if test="count(spell[level = '7']) > 0">
			<xsl:text>7th - </xsl:text>
			<xsl:for-each select="spell[level = '7']">
				<xsl:sort select="string(.)"/>
				<i><xsl:value-of select="name"/><xsl:apply-templates select="count"/></i>
				<xsl:choose>
				<xsl:when test="position() != last()">
					<xsl:text>, </xsl:text>
				</xsl:when>
				</xsl:choose>
			</xsl:for-each>
		</xsl:if>
<br/>
		<xsl:if test="count(spell[level = '8']) > 0">
			<xsl:text>8th - </xsl:text>
			<xsl:for-each select="spell[level = '8']">
				<xsl:sort select="string(.)"/>
				<i><xsl:value-of select="name"/><xsl:apply-templates select="count"/></i>
				<xsl:choose>
				<xsl:when test="position() != last()">
					<xsl:text>, </xsl:text>
				</xsl:when>
				</xsl:choose>
			</xsl:for-each>
		</xsl:if>
<br/>
		<xsl:if test="count(spell[level = '9']) > 0">
			<xsl:text>9th - </xsl:text>
			<xsl:for-each select="spell[level = '9']">
				<xsl:sort select="string(.)"/>
				<i><xsl:value-of select="name"/><xsl:apply-templates select="count"/></i>
				<xsl:choose>
				<xsl:when test="position() != last()">
					<xsl:text>, </xsl:text>
				</xsl:when>
				</xsl:choose>
			</xsl:for-each>
		</xsl:if>
		<xsl:text>.</xsl:text>
	</xsl:for-each>
	<br/><br/>
	<xsl:if test="items/item != ''">
		<b>Possessions:</b><br/>
		<b>Currency: </b>
		<xsl:if test="currency/cp != ''">
			<xsl:value-of select="currency/cp"/>cp;
		</xsl:if>
		<xsl:if test="currency/sp != ''">
			<xsl:value-of select="currency/sp"/>sp;
		</xsl:if>
		<xsl:if test="currency/gp != ''">
			<xsl:value-of select="currency/gp"/>gp;
		</xsl:if>
		<xsl:if test="currency/pp != ''">
			<xsl:value-of select="currency/pp"/>pp;<br/>
		</xsl:if>
		<xsl:if test="items/item[type = 'Weapon'] != ''">
			<br/><b><xsl:text>Weapons: </xsl:text></b>
			<xsl:for-each select="items/item[type = 'Weapon']">
				<xsl:value-of select="name"/>
				<xsl:choose>
				<xsl:when test="position() = last()">
					<xsl:text>.</xsl:text>
				</xsl:when>
				<xsl:otherwise>
					<xsl:text>; </xsl:text>
				</xsl:otherwise>
				</xsl:choose>
			</xsl:for-each>
		</xsl:if>

		<xsl:if test="items/item[type = 'Armor'] != ''">
			<br/><b><xsl:text>Armor: </xsl:text></b>
			<xsl:for-each select="items/item[type = 'Armor']">
				<xsl:value-of select="name"/>
				<xsl:choose>
				<xsl:when test="position() = last()">
					<xsl:text>.</xsl:text>
				</xsl:when>
				<xsl:otherwise>
					<xsl:text>; </xsl:text>
				</xsl:otherwise>
				</xsl:choose>
			</xsl:for-each>
		</xsl:if>

		<xsl:if test="items/item[type = 'Shield'] != ''">
			<br/><b><xsl:text>Shields: </xsl:text></b>
			<xsl:for-each select="items/item[type = 'Shield']">
				<xsl:value-of select="name"/>
				<xsl:choose>
				<xsl:when test="position() = last()">
					<xsl:text>.</xsl:text>
				</xsl:when>
				<xsl:otherwise>
					<xsl:text>; </xsl:text>
				</xsl:otherwise>
				</xsl:choose>
			</xsl:for-each>
		</xsl:if>

		<xsl:if test="items/item[type = 'Goods' or type = 'Art' or type = 'Gem'] != ''">
			<br/><b><xsl:text>Goods: </xsl:text></b>
			<xsl:for-each select="items/item[type = 'Goods' or type = 'Art' or type = 'Gem']">
				<xsl:value-of select="name"/>
				<xsl:text> (</xsl:text>
				<xsl:value-of select="cost/@value"/>
				<xsl:value-of select="cost/@name"/>
				<xsl:text>)</xsl:text>
				<xsl:choose>
				<xsl:when test="position() = last()">
					<xsl:text>.</xsl:text>
				</xsl:when>
				<xsl:otherwise>
					<xsl:text>; </xsl:text>
				</xsl:otherwise>
				</xsl:choose>
			</xsl:for-each>
		</xsl:if>

		<xsl:if test="items/item[type = 'Potion' or type = 'Ring' or type = 'Rod' or type = 'Scroll' or type = 'Staff' or type = 'Wand' or type = 'Wondrous'] != ''">
			<br/><b><xsl:text>Magic: </xsl:text></b>
			<xsl:for-each select="items/item[type = 'Potion' or type = 'Ring' or type = 'Rod' or type = 'Scroll' or type = 'Staff' or type = 'Wand' or type = 'Wondrous']">
				<xsl:value-of select="type"/>:
				<xsl:text> </xsl:text>
				<xsl:value-of select="name"/>
				<xsl:choose>
				<xsl:when test="position() = last()">
					<xsl:text>.</xsl:text>
				</xsl:when>
				<xsl:otherwise>
					<xsl:text>; </xsl:text>
				</xsl:otherwise>
				</xsl:choose>
			</xsl:for-each>
		</xsl:if>
	</xsl:if>
    </td>
  </tr>
  <tr>
    <td align="right">
	<image src="{portrait}" height="150" width="150"/>
    </td>
  </tr>
</table>
</body>
</html>
</xsl:template>


<xsl:template match="count">
	<xsl:if test=". &gt; 1">
		<xsl:text> x</xsl:text><xsl:value-of select="."/>
	</xsl:if>
</xsl:template>

</xsl:stylesheet>










